# Script:	CreateClusteredDTC.ps1
# Author: 	Allan Hirt, SQLHA
# Website: 	http://www.sqlha.com
# Purpose: 	Create a clustered Microsoft Distibutefd Transaction Coordinator 
#		properly in the resource group with SQL Server
#
# Version History:
# 1.0   	9/2/2009 Original version published as part of blog post 
#   		http://tinyurl.com/724bq75
# 2.0    	6/29/2012 Updated for Windows Server 2008 R2
# 3.0  		3/12/2013 Updated to take into account adding to existing instance in production 
#   		that is online already by removing dependency on SQL Server resource
#		Also fixed error due to disk resource not being moved into the SQL Server
#		resource group
#

#
# Windows Failover Cluster name
#
$WSFCnm = STYX

#
# Name of the disk to be used with DTC
#
$DTCdisknm = Drive M

#
# Name of the WSFC resource group that will contain the DTC resource
#
$DTCgrpnm = "EQUINOX"

#
# Name of the SQL Server resource
# For a default instance it will be "SQL Server"
# For a named instance it will be "SQL Server (NMDINS)" where NMDINS is the part after the slash
#
$SQLresnm = "SQL Server"

#
# WSFC Friendly Name of the DTC's IP resource 
# 
$DTCipresnm = "EQUINOXDTCIP"

#
# IP address of the DTC resource 
#
$DTCipaddr = "200.201.202.107"

# 
# Subnet for the DTC IP address 
# 
$DTCsubnet = "255.255.255.0"

#
# WSFC Network to use for the DTC IP address
# This maps to the name in the WSFC for the network that the IP address talks over
#
$DTCnetwk = Public Network

#
# WSFC Friendly Name of the Network Name resource
#
$DTCnetnm = DTC Network Name (EQUINOXDTC)

#
# Name of the WSFC DTC Network Name resource
# Also used for DNS and AD
# Make sure this is right!
#
$DTCresnm = EQUINOXDTC

#
# Create the IP resource
#
Add-ClusterResource -Name $DTCipresnm -ResourceType "IP Address" -Group $DTCgrpnm

#
# Set the network to use, IP address, and subnet
# All three have to be configured at the same time
#
$DTCIPres = Get-ClusterResource $DTCipresnm
$ntwk = New-Object Microsoft.FailoverClusters.PowerShell.ClusterParameter $DTCipres,Network,$DTCnetwk
$ipaddr = New-Object Microsoft.FailoverClusters.PowerShell.ClusterParameter $DTCipres,Address,$DTCipaddr
$subnet = New-Object Microsoft.FailoverClusters.PowerShell.ClusterParameter $DTCipres,SubnetMask,$dtcsubnet

$setdtcipparams = $ntwk,$ipaddr,$subnet
$setdtcipparams | Set-ClusterParameter

#
# Create the Network Name resource
#
Add-ClusterResource $DTCnetnm -ResourceType Network Name -Cluster $WSFCnm -Group $DTCgrpnm

#
# Set the value for the Network Name resource
#
Get-ClusterResource $DTCnetnm -Cluster $WSFCnm | Set-ClusterParameter DnsName $DTCresnm

#
# Add the IP address as a depenency of the Network Name resource
#
Add-ClusterResourceDependency $DTCnetnm $DTCipresnm -Cluster $WSFCnm

#
# Create the Distributed Transaction Coordinator resource
#
Add-ClusterResource $DTCresnm -ResourceType Distributed Transaction Coordinator -Cluster $WSFCnm -Group $DTCgrpnm

#
# Add the Network Name as a depenency of the DTC resource
#
Add-ClusterResourceDependency $DTCresnm $DTCnetnm -Cluster $WSFCnm

#
# Move the disk into the resource group with SQL Server
#
Move-ClusterResource $DTCdisknm -Group $DTCgrpnm -Cluster $WSFCnm

#
# Add the disk as a depenency of the DTC resource
#
Add-ClusterResourceDependency $DTCresnm $DTCdisknm -Cluster $WSFCnm

#
# Bring the IP resource online
#
Start-ClusterResource $DTCipresnm

#
# Bring the Network Name resource online
#
Start-ClusterResource $DTCnetnm

#
# Bring the DTC resource online
#
Start-ClusterResource $DTCresnm